==> gesundheit-0.1.2.tgz: package/lib/insert.js <==
(function() {
  var DEFAULT, Insert, Query, fluid;
  var __hasProp = Object.prototype.hasOwnProperty, __extends = function(child, parent) {
    for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; }
    function ctor() { this.constructor = child; }
    ctor.prototype = parent.prototype;
    child.prototype = new ctor;
    child.__super__ = parent.prototype;
    return child;
  }, __slice = Array.prototype.slice;
  fluid = require('./fluid');
  Query = require('./base-query');
  DEFAULT = require('./dialects/common').DEFAULT;
  module.exports = Insert = (function() {
    var reset;
    __extends(Insert, Query);
    reset = function(fn) {
      return function() {
        var args;
        args = 1 <= arguments.length ? __slice.call(arguments, 0) : [];
        this.s.fields = [];
        this.s.parameters = [];
        return fn.apply(null, args);
      };
    };
    function Insert(table, opts) {
      if (opts == null) {
        opts = {};
      }
      Insert.__super__.constructor.call(this, opts);
      this.s.queryType = 'Insert';
      this.s.table = this.resolve.table(table);
      this.s.fields = [];
      this.s.parameters = [];
    }
    Insert.prototype.fields = fluid(function() {
      var fields;
      fields = 1 <= arguments.length ? __slice.call(arguments, 0) : [];
      return this.s.fields = fields;
    });
    Insert.prototype.addRows = fluid(function() {
      var row, rows, _i, _len, _results;
      rows = 1 <= arguments.length ? __slice.call(arguments, 0) : [];
      _results = [];
      for (_i = 0, _len = rows.length; _i < _len; _i++) {
        row = rows[_i];
        _results.push(row.constructor === Array ? this.addRowArray(row) : this.addRowObject(row));
      }
      return _results;
    });
    Insert.prototype.addRow = function(row) {
      return this.addRows(row);
    };
    Insert.prototype.addRowArray = function(row) {
      var count, _ref;
      if (this.s.fields != null) {
        count = this.s.fields.length;
      }
      if (!count) {
        throw new Error("Cannot insert from array without first setting fields");
      }
      if (row.length !== count) {
        throw new Error("Wrong number of values in array, expected " + this.s.fields);
      }
      return (_ref = this.s.parameters).push.apply(_ref, row);
    };
    Insert.prototype.checkFields = function(cb) {};
    Insert.prototype.addRowObject = function(row) {
      var array, f, _ref;
      if (!this.s.fields || this.s.fields.length === 0) {
        this.s.fields = Object.keys(row);
      }
      array = (function() {
        var _i, _len, _ref, _results;
        _ref = this.s.fields;
        _results = [];
        for (_i = 0, _len = _ref.length; _i < _len; _i++) {
          f = _ref[_i];
          _results.push((row[f] != null) || row[f] === null ? row[f] : DEFAULT);
        }
        return _results;
      }).call(this);
      return (_ref = this.s.parameters).push.apply(_ref, array);
    };
    Insert.prototype.fromQuery = fluid(function(query) {
      this.s.queryType = 'InsertSelect';
      return this.s.fromQuery = query;
    });
    return Insert;
  })();
  Insert.into = function(tbl, opts) {
    return new Insert(tbl, opts);
  };
}).call(this);

==> gesundheit-0.1.3.tgz: package/lib/insert.js <==
(function() {
  var DEFAULT, Insert, Query, fluid;
  var __hasProp = Object.prototype.hasOwnProperty, __extends = function(child, parent) {
    for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; }
    function ctor() { this.constructor = child; }
    ctor.prototype = parent.prototype;
    child.prototype = new ctor;
    child.__super__ = parent.prototype;
    return child;
  }, __slice = Array.prototype.slice;
  fluid = require('./fluid');
  Query = require('./base-query');
  DEFAULT = require('./dialects/common').DEFAULT;
  module.exports = Insert = (function() {
    __extends(Insert, Query);
    function Insert(table, opts) {
      if (opts == null) {
        opts = {};
      }
      Insert.__super__.constructor.call(this, opts);
      this.s.queryType = 'Insert';
      this.s.table = this.resolve.table(table);
      this.s.fields = [];
      this.s.parameters = [];
    }
    Insert.prototype.fields = fluid(function() {
      var fields;
      fields = 1 <= arguments.length ? __slice.call(arguments, 0) : [];
      return this.s.fields = fields;
    });
    Insert.prototype.addRows = fluid(function() {
      var row, rows, _i, _len, _results;
      rows = 1 <= arguments.length ? __slice.call(arguments, 0) : [];
      _results = [];
      for (_i = 0, _len = rows.length; _i < _len; _i++) {
        row = rows[_i];
        _results.push(row.constructor === Array ? this.addRowArray(row) : this.addRowObject(row));
      }
      return _results;
    });
    Insert.prototype.addRow = function(row) {
      return this.addRows(row);
    };
    Insert.prototype.addRowArray = function(row) {
      var count, _ref;
      if (this.s.fields != null) {
        count = this.s.fields.length;
      }
      if (!count) {
        throw new Error("Cannot insert from array without first setting fields");
      }
      if (row.length !== count) {
        throw new Error("Wrong number of values in array, expected " + this.s.fields);
      }
      return (_ref = this.s.parameters).push.apply(_ref, row);
    };
    Insert.prototype.checkFields = function(cb) {};
    Insert.prototype.addRowObject = function(row) {
      var array, f, _ref;
      if (!this.s.fields || this.s.fields.length === 0) {
        this.s.fields = Object.keys(row);
      }
      array = (function() {
        var _i, _len, _ref, _results;
        _ref = this.s.fields;
        _results = [];
        for (_i = 0, _len = _ref.length; _i < _len; _i++) {
          f = _ref[_i];
          _results.push((row[f] != null) || row[f] === null ? row[f] : DEFAULT);
        }
        return _results;
      }).call(this);
      return (_ref = this.s.parameters).push.apply(_ref, array);
    };
    Insert.prototype.fromQuery = fluid(function(query) {
      this.s.queryType = 'InsertSelect';
      this.s.fromQuery = query;
      return this.s.parameters = query.s.parameters;
    });
    return Insert;
  })();
  Insert.into = function(tbl, opts) {
    return new Insert(tbl, opts);
  };
}).call(this);
